@@ -35,4 +35,8 @@ class Cli(cmd.Cmd):
         raise KeyboardInterrupt
 
     def default(self, line):
-        print ("Несуществующая команда")
+        try:
+            print("Команда {line} не существует")
+        
+        except:
+            print("Несуществующая команда")
